==> jc-1.4.0.tar.gz: gnu/java/net/PlainSocketImpl__24SocketInputStream.h <==
// final class gnu.java.net.PlainSocketImpl$SocketInputStream

// class file dependencies
// @dep_class 9ce304a4bffebc3a gnu_java_net_PlainSocketImpl__24SocketInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_gnu_java_net_PlainSocketImpl__24SocketInputStream_H_
#define _JC_gnu_java_net_PlainSocketImpl__24SocketInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainSocketImpl$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_refs	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_refs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_nonrefs	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$refs	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$refs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$nonrefs	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$nonrefs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object;

typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vmethods	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vmethods;
typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtable	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtable;
typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$_init$24fc9fa1db57e8f4(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *, struct _jc_gnu_java_net_PlainSocketImpl$object *);

// Virtual methods
extern jint _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *);
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *);
extern jint _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *);
extern jint _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *);
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vmethods	gnu_java_net_PlainSocketImpl__24SocketInputStream;
};

// Vtype
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_refs {
	struct _jc_gnu_java_net_PlainSocketImpl$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$refs {
    _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_refs	gnu_java_net_PlainSocketImpl__24SocketInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_nonrefs	gnu_java_net_PlainSocketImpl__24SocketInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object {
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype	*vtype;
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_PlainSocketImpl__24SocketInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$class_object;

#endif	/* _JC_gnu_java_net_PlainSocketImpl__24SocketInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/PlainSocketImpl__24SocketInputStream.h <==
// final class gnu.java.net.PlainSocketImpl$SocketInputStream

// class file dependencies
// @dep_class 2860ae1b7fabb344 gnu_java_net_PlainSocketImpl__24SocketInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_gnu_java_net_PlainSocketImpl__24SocketInputStream_H_
#define _JC_gnu_java_net_PlainSocketImpl__24SocketInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainSocketImpl$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_refs	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_refs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_nonrefs	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$refs	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$refs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$nonrefs	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$nonrefs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object;

typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vmethods	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vmethods;
typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtable	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtable;
typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$_init$24fc9fa1db57e8f4(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *, struct _jc_gnu_java_net_PlainSocketImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *) _JC_JCNI_ATTR;
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vmethods	gnu_java_net_PlainSocketImpl__24SocketInputStream;
};

// Vtype
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_refs {
	struct _jc_gnu_java_net_PlainSocketImpl$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$refs {
    _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_refs	gnu_java_net_PlainSocketImpl__24SocketInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$sub_nonrefs	gnu_java_net_PlainSocketImpl__24SocketInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$object {
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype	*vtype;
	_jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$vtype _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_PlainSocketImpl__24SocketInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_PlainSocketImpl__24SocketInputStream$class_object;

#endif	/* _JC_gnu_java_net_PlainSocketImpl__24SocketInputStream_H_ */
